import { NodeValue, ValueType } from "./node-value.js";

export type NodeId = string;
export type NodeQueryIdentifier = string;

export enum NodeType {
  folder = "folder",
  value = "value",
  file = "file",
  method = "method",
  directory = "directory"
}

export enum Type {
  int16 = "int16",
  int32 = "int32",
  int64 = "int64",
  object = "object"
}

export enum HistoryOptions {
  inactive = 'inactive',
  active = 'active',
  valueChange = 'valueChange',
  subscription = 'subscription'
}

export type PathValue = any;

export interface INode {
  name: string;
  parentId: NodeQueryIdentifier | null;

  displayName?: string | null;
  description?: string | null;
  maxValueAge?: number | null;
  pathType?: Type;
  path?: PathValue | null;
}

export interface IValueNode extends INode {
  valueType: ValueType;

  value?: NodeValue;
  location?: string | null;
  historyOptions?: string | null;
  historyInterval?: number | null;
  minValue?: number | null;
  maxValue?: number | null;
  hysteresis?: number | null;
  scalingFactor?: number | null;
  scalingOffset?: number | null;
  unit?: string | null;
  format?: string | null;
}

export class Node implements INode {
  name: string;
  parentId: NodeQueryIdentifier | null;
  type: NodeType;

  displayName?: string;
  description?: string;
  maxValueAge?: number;
  pathType?: Type;
  path?: PathValue | null;

  public constructor(init?: INode) {
    Object.assign(this, init);
  }
}

export class ValueNode extends Node implements IValueNode {
  type = NodeType.value;
  valueType: ValueType;
  
  value?: NodeValue;
  location?: string | null;
  historyOptions?: string | null;
  historyInterval?: number | null;
  minValue?: number | null;
  maxValue?: number | null;
  hysteresis?: number | null;
  scalingFactor?: number | null;
  scalingOffset?: number | null;
  unit?: string | null;
  format?: string | null;

  public constructor(init?: IValueNode) {
    super(init);
    Object.assign(this, init);
  }
}

export class FolderNode extends Node {
  type = NodeType.folder;

  public constructor(init?: INode) {
    super(init);
    Object.assign(this, init);
  }
}

export class DirectoryNode extends Node {
  type = NodeType.folder;

  public constructor(init?: INode) {
    super(init);
    Object.assign(this, init);
  }
}

export class FileNode extends Node {
  type = NodeType.file;
  
  public constructor(init?: INode) {
    super(init);
    Object.assign(this, init);
  }
}

export class MethodNode extends Node {
  type = NodeType.method;

  public constructor(init?: INode) {
    super(init);
    Object.assign(this, init);
  }
}

