/**
 * If you import a dependency which does not include its own type definitions,
 * TypeScript will try to find a definition for it by following the `typeRoots`
 * compiler option in tsconfig.json. For this project, we've configured it to
 * fall back to this folder if nothing is found in node_modules/@types.
 *
 * Often, you can install the DefinitelyTyped
 * (https://github.com/DefinitelyTyped/DefinitelyTyped) type definition for the
 * dependency in question. However, if no one has yet contributed definitions
 * for the package, you may want to declare your own. (If you're using the
 * `noImplicitAny` compiler options, you'll be required to declare it.)
 *
 * This is an example type definition which allows import from `module-name`,
 * e.g.:
 * ```ts
 * import something from 'module-name';
 * something();
 * ```
 */

import { DirectoryNode, FileNode, FolderNode, INode, MethodNode, NodeId, ValueNode } from "./node.js";
import { INodeValue } from "./node-value.js";


export interface IReadNode extends INode {
  id: NodeId;
}

export interface IReadValueNode extends IReadNode {
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  value?: INodeValue;
}

export class ReadValueNode extends ValueNode implements IReadValueNode {
  id: NodeId;
  value?: INodeValue;
}

export class ReadFolderNode extends FolderNode implements IReadNode {
  id: NodeId;
}

export class ReadDirectoryNode extends DirectoryNode implements IReadNode {
  id: NodeId;
}

export class ReadFileNode extends FileNode implements IReadNode {
  id: NodeId;
}

export class ReadMethodNode extends MethodNode implements IReadNode {
  id: NodeId;
}

export type ReadNode = ReadValueNode | ReadFolderNode | ReadDirectoryNode | ReadFileNode | ReadMethodNode;
